# LI-Common

## Versão:

[![PyPi version](https://pypip.in/version/li-common/badge.svg?text=versão)](https://pypi.python.org/pypi/li-common)
[![PyPi downloads](https://pypip.in/download/li-common/badge.svg)](https://pypi.python.org/pypi/li-common)


## Build Status

### Master

[![Build Status](https://travis-ci.org/lojaintegrada/LI-Common.svg?branch=master)](https://travis-ci.org/lojaintegrada/LI-Common)
[![Coverage Status](https://coveralls.io/repos/lojaintegrada/LI-Common/badge.svg?branch=master)](https://coveralls.io/r/lojaintegrada/LI-Common?branch=master)

### Desenvolvimento

[![Build Status](https://travis-ci.org/lojaintegrada/LI-Common.svg?branch=desenvolvimento)](https://travis-ci.org/lojaintegrada/LI-Common)
[![Coverage Status](https://coveralls.io/repos/lojaintegrada/LI-Common/badge.svg?branch=desenvolvimento)](https://coveralls.io/r/lojaintegrada/LI-Common?branch=desenvolvimento)


## Descrição

Estrutura básica para os aplicativos dos subsistemas da LI. As bases para entidades, repositórios, serviços e etc estarão disponíveis nessa lib, que fara o trabalho comum de serializar entidades, formatar saídas de API, validar dados de entrada e etc.
